"""Regression testing framework
This module will search for scripts in the same directory named
test_*.py.  Each such script should be a test suite that tests a
module through PyUnit. This script will aggregate all
found test suites into one big test suite and run them all at once.
"""

# Author: Mark Pilgrim
# Modified by Ole Nielsen

import unittest
import os


#List files that should be excluded from the testing process.
#E.g. if they are known to fail and under development
#exclude = ['test_least_squares.py', 'test_cg_solve.py',
          # 'test_interpolate_sww.py']
exclude = ['test_cg_solve.py']



def regressionTest():
    import sys, os, re, unittest    
    path = os.path.split(sys.argv[0])[0] or os.getcwd()
    files = os.listdir(path)
    test = re.compile('^test_[\w]*.py$', re.IGNORECASE)
    files = filter(test.search, files)

    try:
        files.remove(__file__)  #Remove self from list (Ver 2.3. or later)
    except:
        files.remove('test_all.py') 


    for file in exclude:
        files.remove(file)
        print 'WARNING: File '+ file + ' excluded from testing'
        

    filenameToModuleName = lambda f: os.path.splitext(f)[0]
    moduleNames = map(filenameToModuleName, files)
    modules = map(__import__, moduleNames)
    load = unittest.defaultTestLoader.loadTestsFromModule
    return unittest.TestSuite(map(load, modules))

if __name__ == '__main__':

    os.system('python compile.py') #Attempt to compile all extensions
    
    unittest.main(defaultTest='regressionTest')
    
